ht_sign_into

Function ht_sign_into 

pub fn ht_sign_into<P: Params>(
    m: &[u8],
    sk_seed: &[u8],
    pk_seed: &[u8],
    idx_tree: u64,
    idx_leaf: u32,
    out: &mut [u8],
)
Streaming variant of ht_sign — writes the D * (LEN + H') * N byte hypertree signature into the start of out (which must be at least that size).

Each of the D XMSS signatures is written directly into its slot inside out; the layer-j root is recovered from the slot that was just written (xmss_pk_from_sig) rather than from a temporary per-layer Vec<u8>.