pub fn wots_pk_from_sig<P: Params>(
sig: &[u8],
m: &[u8],
pk_seed: &[u8],
adrs: &mut Adrs,
) -> Vec<u8> ⓘExpand description
Compute a WOTS+ public key candidate from a signature.
Implements Algorithm 8 of FIPS 205. For each digit d_i of the message (including
checksum), completes the hash chain from the signature value (at step d_i) to the
full chain endpoint (step w - 1), then compresses all endpoints with T_len.
If the signature is valid, the returned value equals the original public key.