pub fn wots_sign<P: Params>(
m: &[u8],
sk_seed: &[u8],
pk_seed: &[u8],
adrs: &mut Adrs,
) -> Vec<u8> ⓘExpand description
Sign an n-byte message using WOTS+.
Implements Algorithm 7 of FIPS 205. Converts the message m to base-w digits,
appends the checksum digits, and for each digit d_i outputs the chain value
F^(d_i)(sk_i). The resulting signature is len * n bytes.
This is a one-time signature: using the same WOTS+ key pair to sign two different messages leaks enough information to allow forgery.