pub fn xmss_sign<P: Params>(
m: &[u8],
sk_seed: &[u8],
idx: u32,
pk_seed: &[u8],
adrs: &mut Adrs,
) -> Vec<u8> ⓘExpand description
Create an XMSS signature for an n-byte message.
Implements Algorithm 10 of FIPS 205. Signs message m using the WOTS+ key pair
at leaf index idx and produces an authentication path of h' sibling nodes
that allows the verifier to recompute the tree root.
The returned signature is (len + h') * n bytes: a WOTS+ signature (len * n)
followed by the Merkle authentication path (h' * n).